package com.example.demo.service.impl;

import com.alibaba.fastjson.JSON;
import com.example.demo.constant.EleConstant;
import com.example.demo.constant.StaConstant;
import com.example.demo.mapper.ElectricityBillMapper;
import com.example.demo.model.DataAndView;
import com.example.demo.model.ElectricityBill;
import com.example.demo.model.Response;
import com.example.demo.model.TypeAndQuery;
import com.example.demo.service.BasicService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Slf4j
@Service
public class BasicServiceImpl implements BasicService {

    @Autowired
    ElectricityBillMapper electricityBillMapper;

    @Override
    public Response getElectricityInfo(Map<String, Object> param) {
        String keyWord = (String) param.get("kw");
        Response response = new Response();
        List<ElectricityBill> bills = new ArrayList<>();
        TypeAndQuery typeAndQuery = new TypeAndQuery();
        analysisKeyWord(keyWord,typeAndQuery);
        if (0 == typeAndQuery.getQuerySymbol()){
            log.info("不支持的查询类型");
            response.setSta(StaConstant.UNSUPPORTED_QUERY_TYPE);
            response.setMessage("failed");
            response.setData("暂时还不支持查询此类问题，您可以说查询电费或查询电量");
            return response;
        }
        DataAndView dataAndView =new DataAndView();
        dataAndView.setType(typeAndQuery.getType());
        if (1 == typeAndQuery.getQuerySymbol()){
            log.info("数据库查询电量！");
            response.setSta(StaConstant.UNSUPPORTED_QUERY_TYPE);
            response.setMessage("failed");
            response.setData("电量查询暂未开放！");
            return response;
        }else if (2 == typeAndQuery.getQuerySymbol()){
            log.info("数据库查询电费！");
            bills = electricityBillMapper.queryElectricityByDate();
            dataAndView.setData(bills);
            response.setSta(StaConstant.SUCCESS);
            response.setMessage("success");
            response.setData(dataAndView);
        }else {
            log.info("暂时还没有此类查询！");
            response.setSta(StaConstant.UNSUPPORTED_QUERY_TYPE);
            response.setMessage("failed");
            response.setData("暂时还不支持查询此类问题，您可以说查询电费或查询电量");
            return response;
        }
        return response;
    }


    private void analysisKeyWord(String keyWord,TypeAndQuery typeAndQuery){
        int querySymbol = 0;
        String type = EleConstant.LINE_TYPE_BG;
        typeAndQuery.setType(type);
        typeAndQuery.setQuerySymbol(querySymbol);
        if (keyWord.contains(EleConstant.ELECTRICITY)){
            querySymbol = EleConstant.ELECTRICITY_SYMBOL;
            typeAndQuery.setQuerySymbol(querySymbol);
        }else if (keyWord.contains(EleConstant.QUANTITY_OF_ELECTRICITY)){
            querySymbol = EleConstant.QUANTITY_OF_ELECTRICITY_SYMBOL;
            typeAndQuery.setQuerySymbol(querySymbol);
        }
        for (String val:EleConstant.barList){
            if (keyWord.contains(val)){
                type = EleConstant.LINE_TYPE_ZZ;
                typeAndQuery.setType(type);
                return;
            }
        }
        for (String val:EleConstant.lineList){
            if (keyWord.contains(val)){
                type = EleConstant.LINE_TYPE_ZX;
                typeAndQuery.setType(type);
                return;
            }
        }
        for (String val:EleConstant.pieList){
            if (keyWord.contains(val)){
                type = EleConstant.LINE_TYPE_SX;
                typeAndQuery.setType(type);
                return;
            }
        }
    }
}
